
source("R/OSMDownload/tags.r")

library(rgdal)
library(sp)
library(rgeos)
library(stplanr)
library(maps)


#' DoBuffer
#'
#' Create a buffer zone from the polygon.
#'
#' @param inactoPath Path to the polygon Shapefile
#' @param inmeters Size of the buffer zone in meters
#' @param toplot Boolean for ploting the results
#'
#' @return
#' @export
#'
#' @examples library(goal)
#' library(sp)
#' library(rgeos)
#' library(stplanr)
#' library(maps)
#' library(rgdal)
#' DoBuffer(inactoPath="DataOSM/01.shp", inmeters=-1000, toplot=1)
DoBuffer <- function(inactoPath, inmeters=-1000, toplot=1){

  acto=rgdal::readOGR(dsn=inactoPath )
  bf = stplanr::buff_geo(acto, width=inmeters)
  bf2 =  sp::spTransform(bf, sp::proj4string(acto) )
  zone = rgeos::gDifference(acto, bf2)

  if(toplot){
    par(mar = c(1, 1, 4, 1))
    plot(acto, main=sprintf("Zone of %s km",  (inmeters/1000) ))
    grid()
    plot(acto, add=T, col="red" )
    plot(zone, add=T,col="green")
    legend("topleft", legend=c("Excluded zone", "Selection zone"), fill =c("red", "green"), cex=1)
    box()
    maps::map.scale(   relwidth = 0.1, ratio =T )
  }


}

#DoBuffer(inactoPath="DataOSM/01.shp", inmeters=-1000, toplot=1)





