

# ====================   Points Along Lines   ======================




#' Generate Points Along Lines
#' 
#' Generate points along lines. 
#' 
#' @title Points Along Lines
#' @param inroads A \code{\link{SpatialLines}} or \code{\link{SpatialPointsDataFrame}} object
#' @param thefactor A general multiplier factor whch determines the number of points to be generated.  
#' @return A \code{\link{SpatialPointsDataFrame}} object which holds the points
#' 
#' @author Dimitris Kavroudakis \email{dimitris123@@gmail.com}
#' @export
#' @keywords geometry
#' @family geo
#' @import sp
#' @importFrom rgeos gLength
#' @examples library(goal)
#' library(sp)
#' library(rgeos)
#' x = c(1,2,2,1,1,1,3,3)
#' y = c(1,3,4,7,8,9,13,21)
#' thefactor=2 
#' road = sp::SpatialLines(list(sp::Lines(Line(cbind(x,y)), ID="a")))
#' 
#' result = geo.PointsAlongLines(road, thefactor = thefactor)
#' plot(road)
#' plot(result, add=TRUE)
#' 
geo.PointsAlongLines = function(inroads, thefactor) {
  p= spsample(inroads, rgeos::gLength(inroads)*thefactor, type="regular")
  p = sp::SpatialPointsDataFrame(p, data=data.frame(id=1:length(p)  )  )
  return(p)
}

